/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RulePackageEB.java 4915 2009-08-14 11:57:56Z nicoulaj $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.rules.manager.ejb;

import java.io.Serializable;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.Table;

import org.ow2.jasmine.rules.manager.model.AbstractRulePackage;
import org.ow2.jasmine.rules.manager.model.IRulePackage;
import org.ow2.jasmine.rules.manager.model.textual.ITextualRulePackage;
import org.ow2.jasmine.rules.manager.model.visual.IVisualRulePackage;

/**
 * The RulePackage entity bean. Represents the abstract class
 * {@link AbstractRulePackage} and refers to either a {@link TextualRulePackageEB}
 * or a {@link VisualRulePackageEB} object.
 *
 * @author HAN Tianyi
 * @author Julien Nicoulaud
 * @see {@link IRulePackage}
 * @see {@link ITextualRulePackage}
 * @see {@link IVisualRulePackage}
 */
@Entity
@Table(name = "RULE_PACKAGE")
public class RulePackageEB implements Serializable {

    // =========================================================================
    // Properties
    // =========================================================================

    /**
     * Class version ID
     */
    private static final long serialVersionUID = 3603043818875621406L;

    /**
     * Primary key
     */
    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private int id;

    // AbstractRulePackage class data fields

    /**
     * The unique system name of the rule package. Identifies the object, must
     * be different for each rule package. Automatically generated from the rule
     * package "display" name.
     *
     * @example "org.ow2.jasmine.monitoring.rules.example.ExamplePackage"
     */
    private String systemName;

    /**
     * The displayed name of the rule package. This is the name that is choosed
     * by the user. Used to generate automatically the systemName property.
     *
     * @example "Example Package"
     */
    private String displayName;

    /**
     * The name of the rule engine instance on which the rule is executed.
     */
    private String ruleEngineInstanceName;

    /**
     * The state of the rule package. Values can be:
     */
    private String state;

    /**
     * The description of the rule package
     */
    private String description;


    // Textual/Visual rule package class references

    /**
     * The entity bean of textual rule package
     */
    @OneToOne
    @JoinColumn(name = "textualRPId")
    private TextualRulePackageEB textualRulePackageEB;

    /**
     * The entity bean of visual rule package
     */
    @OneToOne
    @JoinColumn(name = "visualRPId")
    private VisualRulePackageEB visualRulePackageEB;


    // =========================================================================
    // Getters & setters
    // =========================================================================

    /**
     * Get the id
     */
    public final int getId() {
        return id;
    }

    /**
     * Get the system name
     */
    public final String getSystemName() {
        return systemName;
    }

    /**
     * Set the system name
     */
    public final void setSystemName(final String value) {
        this.systemName = value;
    }

    /**
     * Get the display name
     */
    public final String getDisplayName() {
        return displayName;
    }

    /**
     * Set the display name
     */
    public final void setDisplayName(final String value) {
        this.displayName = value;
    }

    /**
     * Set the name of the rule engine instance on which the rule is executed
     */
    public final void setRuleEngineInstanceName(final String value) {
        ruleEngineInstanceName = value;
    }

    /**
     * Set the name of the rule engine instance on which the rule is executed
     */
    public final String getRuleEngineInstanceName() {
        return ruleEngineInstanceName;
    }

    /**
     * Get the state
     */
    public final String getState() {
        return state;
    }

    /**
     * Set the state
     */
    public final void setState(final String value) {
        this.state = value;
    }

    /**
     * Get the description
     */
    public final String getDescription() {
        return description;
    }

    /**
     * Set the description
     */
    public final void setDescription(final String value) {
        this.description = value;
    }

    /**
     * Get the associated textual rule package
     */
    public final TextualRulePackageEB getTextualRulePackageEB() {
        return textualRulePackageEB;
    }

    /**
     * Set the associated textual rule package
     */
    public final void setTextualRulePackageEB(final TextualRulePackageEB value) {
        this.textualRulePackageEB = value;
    }

    /**
     * Get the associated visual rule package
     */
    public final VisualRulePackageEB getVisualRulePackageEB() {
        return visualRulePackageEB;
    }

    /**
     * Set the associated visual rule package
     */
    public final void setVisualRulePackageEB(final VisualRulePackageEB value) {
        this.visualRulePackageEB = value;
    }

}
